@@ -7,7 +7,18 @@
 """Root of katcp package.
    """
 
-from .katcp import Message, KatcpSyntaxError, MessageParser, \
+import logging
+
+class NullHandler(logging.Handler):
+    def emit(self, record):
+        pass
+
+logging.getLogger("katcp").addHandler(NullHandler())
+
+del logging, NullHandler
+
+
+from .core import Message, KatcpSyntaxError, MessageParser, \
                   DeviceMetaclass, ExcepthookThread, FailReply, \
                   AsyncReply, KatcpDeviceError, KatcpClientError, \
                   Sensor
@@ -16,4 +27,6 @@ from .server import DeviceServerBase, DeviceServer, DeviceLogger
 
 from .client import DeviceClient, BlockingClient, CallbackClient
 
+from .sensortree import GenericSensorTree, BooleanSensorTree, AggregateSensorTree
+
 from .version import VERSION, VERSION_STR
