@@ -10,11 +10,14 @@
 import inspect
 import struct
 import re
-from .katcp import Message, FailReply
+from .core import Message, FailReply
 
 # KATCP Type Classes
 #
 
+# XXX how about a mapping from python types -> kattypes, so creating
+#     a sensor would not require importing kattypes
+
 class KatcpType(object):
     """Class representing a KATCP type.
 
