@@ -8,10 +8,12 @@
    """
 
 import unittest
-import test_katcp
+from katcp.tx import test as tx
 import test_client
+import test_core
 import test_kattypes
 import test_sampling
+import test_sensortree
 import test_server
 
 try:
@@ -24,10 +26,12 @@ except ImportError:
 def suite():
     loader = unittest.TestLoader()
     suite = unittest.TestSuite()
-    suite.addTests(loader.loadTestsFromModule(test_katcp))
+    suite.addTest(tx.suite())
     suite.addTests(loader.loadTestsFromModule(test_client))
+    suite.addTests(loader.loadTestsFromModule(test_core))
     suite.addTests(loader.loadTestsFromModule(test_kattypes))
     suite.addTests(loader.loadTestsFromModule(test_sampling))
+    suite.addTests(loader.loadTestsFromModule(test_sensortree))
     suite.addTests(loader.loadTestsFromModule(test_server))
     if ply is not None:
         suite.addTests(loader.loadTestsFromModule(test_katcp_bnf))
