@@ -3,6 +3,7 @@
 API
 """
 
-from katcp.tx.core import DeviceServer, DeviceProtocol, ClientKatCP
+from katcp.tx.core import (DeviceServer, DeviceProtocol, ClientKatCPProtocol,
+                           KatCPServer, KatCP, ServerKatCPProtocol, run_client)
 from katcp.tx.proxy import DeviceHandler, ProxyProtocol, ProxyKatCP
 
