@@ -1,10 +1,12 @@
 
+from zope.interface import implements
 from twisted.protocols.basic import LineReceiver
 from twisted.internet.defer import Deferred, DeferredList
 from twisted.internet import reactor
 from twisted.internet.protocol import ClientCreator
 from twisted.internet.protocol import Factory
 from twisted.python import log
+from twisted.internet.interfaces import IConsumer, IPushProducer
 from katcp import MessageParser, Message, AsyncReply
 from katcp.core import FailReply
 from katcp.server import DeviceLogger, construct_name_filter
@@ -48,10 +50,12 @@ class KatCP(LineReceiver):
 
     delimiter = '\n'
     MAX_LENGTH = 64*(2**20) # 64 MB should be fine
+    producing = True
 
     def __init__(self):
         self.parser = MessageParser()
         self.queries = []
+        self.queue = []
 
     def send_request(self, name, *args):
         if not self.transport.connected:
@@ -90,6 +94,9 @@ class KatCP(LineReceiver):
     def inform_disconnect(self, args):
         pass # unnecessary, we have a callback on loseConnection
 
+    def inform_client_connected(self, args):
+        pass # ignored by default
+
     def handle_inform(self, msg):
         # if we have a request being processed, store all the informs
         # in a list of stuff to process
@@ -109,9 +116,8 @@ class KatCP(LineReceiver):
 
     def handle_request(self, msg):
         name = msg.name
-        name = name.replace('-', '_')
         try:
-            rep_msg = getattr(self, 'request_' + name, self._request_unknown)(msg)
+            rep_msg = getattr(self, 'request_' + name.replace('-', '_'), self._request_unknown)(msg)
             if not isinstance(rep_msg, Message):
                 raise ShouldReturnMessage('request_' + name + ' should return a'
                                           'message or raise AsyncReply, instead'
@@ -139,9 +145,26 @@ class KatCP(LineReceiver):
         self.queries.pop(0) # hopefully it's not large
         d.callback((queue, msg))
 
+    # IPushProducer interface
+    implements(IPushProducer)
+        
+    def pauseProducing(self):
+        self.producing = False
+    stopProducing = pauseProducing
+
+    def resumeProducing(self):
+        for msg in self.queue:
+            self.transport.write(str(msg) + self.delimiter)
+        self.queue = []
+        self.producing = True
+
     def send_message(self, msg):
         # just serialize a message
-        self.transport.write(str(msg) + self.delimiter)
+        if self.producing:
+            self.transport.write(str(msg) + self.delimiter)
+        else:
+            self.queue.append(msg)
+        # otherwise we're unable to carry it, drop on the floor
 
     def connectionLost(self, failure):
         # errback all waiting queries
@@ -150,27 +173,125 @@ class KatCP(LineReceiver):
             d.errback(failure)
         self.queries = []
 
-class ClientKatCP(KatCP):
+    def _request_unknown(self, msg):
+        return Message.reply(msg.name, "invalid", "Unknown request.")
+
+class ClientKatCPProtocol(KatCP):
     def inform_log(self, msg):
         """ Default inform when logging event happens. Ignore by default,
         can be overriden
         """
         pass
 
-class ServerFactory(Factory):
-    def __init__(self):
-        self.sensors = {}
-        self.setup_sensors()
-
-    def add_sensor(self, sensor):
-        self.sensors[sensor.name] = sensor
-
-    def setup_sensors(self):
-        pass # override to provide some sensors
-
-class DeviceProtocol(KatCP):
+class ServerKatCPProtocol(KatCP):
     VERSION = ("device_stub", 0, 1)
     BUILD_STATE = ("name", 0, 1, "")
+    
+    def connectionMade(self):
+        """ Called when connection is made. Send default informs - version
+        and build data
+        """
+        self.transport.registerProducer(self, True)
+        self.send_message(Message.inform("version", *self.VERSION))
+        self.send_message(Message.inform("build-state", *self.BUILD_STATE))
+
+    def request_help(self, msg):
+        """Return help on the available requests.
+
+        Return a description of the available requests using a seqeunce of #help informs.
+
+        Parameters
+        ----------
+        request : str, optional
+            The name of the request to return help for (the default is to return help for all requests).
+
+        Informs
+        -------
+        request : str
+            The name of a request.
+        description : str
+            Documentation for the named request.
+
+        Returns
+        -------
+        success : {'ok', 'fail'}
+            Whether sending the help succeeded.
+        informs : int
+            Number of #help inform messages sent.
+
+        Examples
+        --------
+        ::
+
+            ?help
+            #help halt ...description...
+            #help help ...description...
+            ...
+            !help ok 5
+
+            ?help halt
+            #help halt ...description...
+            !help ok 1
+        """
+        if msg.arguments:
+            name = msg.arguments[0]
+            meth = getattr(self, 'request_' + name.replace('-', '_'), None)
+            if meth is None:
+                return Message.reply('help', 'fail', 'Unknown request method.')
+            doc = meth.__doc__
+            if doc is not None:
+                doc = doc.strip()
+            self.send_message(Message.inform('help', name, doc))
+            return Message.reply('help', 'ok', '1')
+        count = 0
+        for name in dir(self.__class__):
+            item = getattr(self, name)
+            if name.startswith('request_') and callable(item):
+                sname = name[len('request_'):].replace('_', '-')
+                doc = item.__doc__
+                if doc is not None:
+                    doc = doc.strip()
+                self.send_message(Message.inform('help', sname, doc))
+                count += 1
+        return Message.reply(msg.name, "ok", str(count))
+
+class KatCPServer(Factory):
+    protocol = ServerKatCPProtocol
+    
+    def __init__(self, port, host):
+        self.clients = {}
+        self.listen_port = port
+        self.host = host
+        self.clients = {}
+    
+    def start(self):
+        self.port = reactor.listenTCP(self.listen_port, self,
+                                      interface=self.host)
+        return self.port
+
+    def register_client(self, addr, protocol):
+        self.clients[addr] = protocol
+
+    def deregister_client(self, addr):
+        del self.clients[addr]
+
+    def stop(self):
+        for client in self.clients.values():
+            client.transport.loseConnection()
+        self.port.stopListening()
+        if getattr(self, 'production', None):
+            reactor.stop()
+
+    def buildProtocol(self, addr):
+        protocol = Factory.buildProtocol(self, addr)
+        self.register_client((addr.host, addr.port), protocol)
+        return protocol
+
+    def mass_inform(self, msg):
+        for client in self.clients.itervalues():
+            client.send_message(msg)
+
+class DeviceProtocol(ServerKatCPProtocol):
 
     SAMPLING_STRATEGIES = {'period'       : PeriodicStrategy,
                            'none'         : NoStrategy,
@@ -182,16 +303,10 @@ class DeviceProtocol(KatCP):
         KatCP.__init__(self, *args, **kwds)
         self.strategies = {}
 
-    def connectionMade(self):
-        """ Called when connection is made. Send default informs - version
-        and build data
-        """
-        self.send_message(Message.inform("version", *self.VERSION))
-        self.send_message(Message.inform("build-state", *self.BUILD_STATE))
-
-
     def connectionLost(self, _):
         self.factory.deregister_client(self.transport.client)
+        for strat in self.strategies.values():
+            strat.cancel()
 
     def read_formatted_from_sensor(self, sensor, callback, fail,
                                    lst_of_deferreds=None):
@@ -358,66 +473,6 @@ class DeviceProtocol(KatCP):
                                              *sensor.formatted_params))
         return Message.reply(msg.name, "ok", len(sensors))
 
-    def request_help(self, msg):
-        """Return help on the available requests.
-
-        Return a description of the available requests using a seqeunce of #help informs.
-
-        Parameters
-        ----------
-        request : str, optional
-            The name of the request to return help for (the default is to return help for all requests).
-
-        Informs
-        -------
-        request : str
-            The name of a request.
-        description : str
-            Documentation for the named request.
-
-        Returns
-        -------
-        success : {'ok', 'fail'}
-            Whether sending the help succeeded.
-        informs : int
-            Number of #help inform messages sent.
-
-        Examples
-        --------
-        ::
-
-            ?help
-            #help halt ...description...
-            #help help ...description...
-            ...
-            !help ok 5
-
-            ?help halt
-            #help halt ...description...
-            !help ok 1
-        """
-        if msg.arguments:
-            name = msg.arguments[0]
-            meth = getattr(self, 'request_' + name.replace('-', '_'), None)
-            if meth is None:
-                return Message.reply('help', 'fail', 'Unknown request method.')
-            doc = meth.__doc__
-            if doc is not None:
-                doc = doc.strip()
-            self.send_message(Message.inform('help', name, doc))
-            return Message.reply('help', 'ok', '1')
-        count = 0
-        for name in dir(self.__class__):
-            item = getattr(self, name)
-            if name.startswith('request_') and callable(item):
-                sname = name[len('request_'):]
-                doc = item.__doc__
-                if doc is not None:
-                    doc = doc.strip()
-                self.send_message(Message.inform('help', sname, doc))
-                count += 1
-        return Message.reply(msg.name, "ok", str(count))
-
     def request_sensor_sampling(self, msg):
         """Configure or query the way a sensor is sampled.
 
@@ -473,7 +528,7 @@ class DeviceProtocol(KatCP):
                 return Message.reply(msg.name, "fail", "Unknown strategy name.")
         # stop the previous strategy
         try:
-            self.strategies[sensor.name].cancel()
+            strategy = self.strategies[sensor.name].cancel()
         except KeyError:
             pass
         strategy = StrategyClass(self, sensor)
@@ -599,43 +654,22 @@ class DeviceProtocol(KatCP):
                 raise FailReply(str(e))
         return Message.reply("log-level", "ok", self.factory.log.level_name())
 
-    def _request_unknown(self, msg):
-        return Message.reply(msg.name, "invalid", "Unknown request.")
-
-class DeviceServer(ServerFactory):
+class DeviceServer(KatCPServer):
     """ This is a device server listening on a given port and address
     """
     protocol = DeviceProtocol
 
+    def add_sensor(self, sensor):
+        self.sensors[sensor.name] = sensor
+
+    def setup_sensors(self):
+        pass # override to provide some sensors
+
     def __init__(self, port, host):
         self.log = DeviceLogger(self) # python logger is None
-        ServerFactory.__init__(self)
-        self.listen_port = port
-        self.host = host
-        self.clients = {}
-
-    def start(self):
-        self.port = reactor.listenTCP(self.listen_port, self,
-                                      interface=self.host)
-        return self.port
-
-    def register_client(self, addr, protocol):
-        self.clients[addr] = protocol
-
-    def deregister_client(self, addr):
-        del self.clients[addr]
-
-    def buildProtocol(self, addr):
-        protocol = ServerFactory.buildProtocol(self, addr)
-        self.register_client((addr.host, addr.port), protocol)
-        return protocol
-
-    def stop(self):
-        for client in self.clients.values():
-            client.transport.loseConnection()
-        self.port.stopListening()
-        if getattr(self, 'production', None):
-            reactor.stop()
+        KatCPServer.__init__(self, port, host)
+        self.sensors = {}
+        self.setup_sensors()
 
     def _log_msg(self, level_name, msg, name, timestamp=None):
         """Create a katcp logging inform message.
@@ -652,7 +686,3 @@ class DeviceServer(ServerFactory):
                 name,
                 msg,
         )
-
-    def mass_inform(self, msg):
-        for client in self.clients.itervalues():
-            client.send_message(msg)
