@@ -1,5 +1,5 @@
 
-from katcp.tx.core import ClientKatCP, DeviceServer, DeviceProtocol
+from katcp.tx.core import ClientKatCPProtocol, DeviceServer, DeviceProtocol
 from katcp import Message, Sensor
 from katcp.tx.test.testserver import run_subprocess
 from twisted.trial.unittest import TestCase
@@ -9,8 +9,8 @@ from twisted.internet.protocol import ClientCreator
 from twisted.internet.base import DelayedCall
 from katcp.core import FailReply
 
-DelayedCall.debug = True
-Deferred.debug = True
+#DelayedCall.debug = True
+#Deferred.debug = True
 
 timeout = 5
 
@@ -26,13 +26,13 @@ class TestKatCP(TestCase):
         def connected(protocol):
             protocol.send_request('halt')
 
-        d, process = run_subprocess(connected, ClientKatCP)
+        d, process = run_subprocess(connected, ClientKatCPProtocol)
         return d
 
     def test_version_check(self):
-        class TestKatCP(ClientKatCP):
+        class TestKatCP(ClientKatCPProtocol):
             def inform_build_state(self, args):
-                ClientKatCP.inform_build_state(self, args)
+                ClientKatCPProtocol.inform_build_state(self, args)
                 # check that version is already set
                 assert self.version == 'device_stub-0.1'
                 self.send_request('halt')
@@ -43,13 +43,16 @@ class TestKatCP(TestCase):
     def test_help(self):
         def received_help((msgs, reply_msg), protocol):
             assert len(msgs) == 9
+            requests = set(msg.arguments[0] for msg in msgs)
+            assert 'help' in requests
+            assert 'sensor-list' in requests
             protocol.send_request('halt')
 
         def connected(protocol):
             d = protocol.send_request('help')
             d.addCallback(received_help, protocol)
 
-        d, process = run_subprocess(connected, ClientKatCP)
+        d, process = run_subprocess(connected, ClientKatCPProtocol)
         return d
 
     def test_callback_sensor_sampling(self):
@@ -85,9 +88,9 @@ class TestFactory(DeviceServer):
         sensor._timestamp = 1
         self.add_sensor(sensor)
 
-class TestClientKatCP(ClientKatCP):
+class TestClientKatCP(ClientKatCPProtocol):
     def __init__(self, *args, **kwds):
-        ClientKatCP.__init__(self, *args, **kwds)
+        ClientKatCPProtocol.__init__(self, *args, **kwds)
         self.status_updates = []
 
     def inform_sensor_status(self, msg):
@@ -129,6 +132,9 @@ class TestDeviceServer(TestCase):
         def help((informs, reply), protocol):
             self.assertEquals(len(informs), count)
             assert 'request' not in informs[0].arguments[0]
+            requests = set(m.arguments[0] for m in informs)
+            assert 'help' in requests
+            assert 'sensor-list' in requests
             self.assertEquals(reply, Message.reply('help', "ok", str(count)))
 
         return self._base_test(('help',), help)
@@ -435,7 +441,7 @@ class TestDeviceServer(TestCase):
 
     def test_fail(self):
         class FaultyProtocol(DeviceProtocol):
-            def request_foobar(self, msg):
+            def request_foo_bar(self, msg):
                 raise FailReply("failed")
 
         class FaultyFactory(TestFactory):
@@ -443,9 +449,9 @@ class TestDeviceServer(TestCase):
 
         def reply((informs, reply), protocol):
             self.assertEquals(informs, [])
-            self.assertEquals(reply, Message.reply("foobar", "fail", "failed"))
+            self.assertEquals(reply, Message.reply("foo-bar", "fail", "failed"))
 
-        return self._base_test(('foobar',), reply, cls=FaultyFactory)
+        return self._base_test(('foo-bar',), reply, cls=FaultyFactory)
 
     def test_client_list(self):
         def got_client_list(values, protocols):
@@ -493,7 +499,7 @@ class TestDeviceServer(TestCase):
         return finish
 
     def test_log_basic(self):
-        class TestProtocol(ClientKatCP):
+        class TestProtocol(ClientKatCPProtocol):
             def inform_log(self, msg):
                 got_log.callback(msg)
 
@@ -531,9 +537,9 @@ class TestDeviceServer(TestCase):
         return self._base_test(('watchdog',), callback)
 
     def test_log_level(self):
-        class TestProtocol(ClientKatCP):
+        class TestProtocol(ClientKatCPProtocol):
             def __init__(self, *args, **kwds):
-                ClientKatCP.__init__(self, *args, **kwds)
+                ClientKatCPProtocol.__init__(self, *args, **kwds)
                 self.msgs = []
 
             def inform_log(self, msg):
